///////////////////////////////////////////////////////////////////////////////////////////////////
//
//	This script contains all UI setting of Gadget
//	Date: 		April 19, 2007
//	Version:	1.1.2
//	Developer:	Pranav Dixit
//
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// GLOBAL GADGET MEMBERS
//
///////////////////////////////////////////////////////////////////////////////////////////////////
// ??????
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// initGadget - initializes the gadget
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function initGadget() {   // init gadget

    // init global vars
    gDockFlag = System.Gadget.docked;                                       // init global gadget docked flag
    gFlyOpenFlag = System.Gadget.Flyout.show;                               // init global flyout open flag

    // get settings
    var sSetting = readSetting("UndockSmallFlag");          // read undock small flag setting
    if (sSetting === '') {
        // default to gUndockSmallFlag = true (if UndockSmallFlag not yet set) 
        gUndockSmallFlag = true;                                            // update global undock small flag
        saveSetting("UndockSmallFlag", gUndockSmallFlag);  // write new setting
    } else {
        gUndockSmallFlag = !!sSetting;                                      // !! forces type conversion to boolean
    }

    // init settings event methods
    System.Gadget.settingsUI = "settings.htm";                              // set settings page
    System.Gadget.onShowSettings = procSettingsShowEvent;                   // set settings onshow method
    System.Gadget.onSettingsClosed = procSettingsClosedEvent;               // set settings onclosed method
    
    // init dock/undock event methods
    System.Gadget.onUndock = procUndockEvent;                               // set gadget onundock method
    System.Gadget.onDock = procDockEvent;                                   // set gadget ondock method

    // init flyout event methods
    System.Gadget.Flyout.file = "flyout.htm";                               // set flyout page
    System.Gadget.Flyout.onShow = procFlyoutShowEvent;                      // set gadget flyout show event
    System.Gadget.Flyout.onHide = procFlyoutHideEvent;                      // set gadget flyout hide event

    gadgetContentFrame.style.visibility = "hidden";
    gadgetDockedFrame.style.visibility = "visible";
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procGadgetCore - process core gadget code
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procGadgetCore() {   // process core gadget code
    initHoroSettings();
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// genGadgetLayout - determine if gadget is in sidebar (docked) or on the desktop 
//                   (undocked) and gen layout based on the current state.
///////////////////////////////////////////////////////////////////////////////////////////////////
function genGadgetLayout() {   // generate gadget layout

    // proc based on docked/undocked status
    if(!gDockFlag) {
        // gen undocked gadget layout
        genUndocked();
    } else {
        // gen docked gadget layout (default action if gDockFlag not set)
        genDocked();
    }
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procDockEvent - process dock event
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procDockEvent() {   // process dock event

    gDockFlag = true;
    genDocked();
    procGadgetCore();
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procUndockEvent - process undock event
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procUndockEvent() {   // process undock event

    gDockFlag = false;
    genUndocked();
    procGadgetCore();
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// genUndocked - gen undocked gadget layout
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function genUndocked() {   // gen undocked gadget layout

    if (gUndockSmallFlag) {
        // gen undocked gadget with small frame
        genUndockedSmallFrame();
    } else {
        // gen undocked gadget with large frame
        genUndockedLargeFrame();
    }
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procFlyoutShowEvent - process show flyout event
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procFlyoutShowEvent() {   // process show flyout event
    gFlyOpenFlag = true;
    genDockedFlyout();
    //////procGadgetCore();
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procFlyoutHideEvent - process hide flyout event
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procFlyoutHideEvent() {   // process hide flyout event

    gFlyOpenFlag = false;
    genDocked();
    procGadgetCore();
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procSettingsShowEvent - process show settings event
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procSettingsShowEvent() {   // process show settings event

    // * NOTE - the settings show event is not currently used by the gadget

}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procSettingsClosing - process settings closing event (settings page is about to close)
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procSettingsClosingEvent(event) { // process settings closing event

    if (event.closeAction == event.Action.commit) {
        procSaveSettings();
    } else if(event.closeAction == event.Action.cancel) {
        //???ADD SOMETHING???(cancel selected - do nothing)???(add below line of code???)???
    }
    event.cancel = false;   //???CORRECT???
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procSettingsClosedEvent - process settings closed event
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procSettingsClosedEvent(event) {   // process settings closed event

   if (event.closeAction == event.Action.commit) {
       loadMain();
   }
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// procSaveSettings - save the new settings
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function procSaveSettings() {   
    //saveSetting("LastSunSign", gLastSunSign);
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// genUndockedSmallFrame - gen layout for undocked gadget with small frame
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function genUndockedSmallFrame() {   // process undocked gadget layout with small frame
    // set gadget document styles
    document.body.style.width = "244px";                                            // set total gadget width
    document.body.style.height = "261px";                                           // set total gadget height
    System.Gadget.background="url(images/backgrounds/bodyFrame.png)";         // set gadget background image
    // * NOTE - the above gadget document width and height settings should be set 
    //          to the same dimensions as the size of the above background image.
    
    // set main gadget frame styles
    gadgetMainFrame.style.width = "244px";                                          // set main frame width
    gadgetMainFrame.style.height = "261px";                                         // set main frame height
    gadgetMainFrame.style.top = "0px";                                              // set main frame top position
    gadgetMainFrame.style.left = "0px";                                             // set main frame left position
    gadgetMainFrame.style.backgroundImage="url()";                                  // clear nav frame background image

    // set content frame styles
    gadgetDockedFrame.style.visibility = "hidden";
    gadgetContentFrame.style.visibility = "visible";
    gadgetContentFrame.style.display = "block"                                      // set content frame display style (show frame)
    gadgetContentFrame.style.width = "236px";                                       // set content frame width
    gadgetContentFrame.style.height = "188px";                                      // set content frame height
    
    // set nav bar content styles
    //gadgetNavDocked.style.display = "none";                                         // set nav bar content (for docked without fly) display style
    //gadgetNavUndockedSmall.style.display = "block";                                 // set nav bar content (for undocked small) display style
    //gadgetNavUndockedLarge.style.display = "none";                                  // set nav bar content (for undocked large) display style
            
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// genUndockedLargeFrame - gen layout for undocked gadget with large frame
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function genUndockedLargeFrame() {   // process undocked gadget layout with large frame
    // set gadget document styles
    document.body.style.width = "244px";                                            // set total gadget width
    document.body.style.height = "261px";                                           // set total gadget height
    System.Gadget.background="url(images/backgrounds/bodyFrame.png)";         // set gadget background image
    // * NOTE - the above gadget document width and height settings should be set 
    //          to the same dimensions as the size of the above background image.
    // set main gadget frame styles
    gadgetMainFrame.style.width = "244px";                                          // set main frame width
    gadgetMainFrame.style.height = "261px";                                         // set main frame height
    gadgetMainFrame.style.top = "0px";                                              // set main frame top position
    gadgetMainFrame.style.left = "0px";                                             // set main frame left position
   
    // set nav bar content styles
    gadgetNavDocked.style.display = "none";                                         // set nav bar content (for docked without fly) display style
    gadgetNavUndockedSmall.style.display = "none";                                  // set nav bar content (for undocked small) display style
    gadgetNavUndockedLarge.style.display = "block";                                 // set nav bar content (for undocked large) display style
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// genDocked - gen docked gadget layout
// 
///////////////////////////////////////////////////////////////////////////////////////////////////
function genDocked() {   // process docked gadget layout with flyout closed (hidden)
    // set gadget document styles
    document.body.style.width = "130px";                                            // set total gadget width
    document.body.style.height = "200px";                                           // set total gadget height
    System.Gadget.background="url()";         							// set gadget background image
    // * NOTE - the above gadget document width and height settings should be set 
    //          to the same dimensions as the size of the above background image.
    
    // set main gadget frame styles
    gadgetMainFrame.style.width = "130px";                                          // set main frame width
    gadgetMainFrame.style.height = "200px";                                         // set main frame height
    gadgetMainFrame.style.top = "0px";                                              // set main frame top position
    gadgetMainFrame.style.left = "0px";                                             // set main frame left position
    gadgetMainFrame.style.backgroundImage="url()";                                  // clear nav frame background image
    
    // set nav bar content styles
    gadgetContentFrame.style.visibility = "hidden";
    gadgetDockedFrame.style.visibility = "visible";
    gadgetDockedFrame.style.display = "block"                                      // set content frame display style (show frame)
    gadgetDockedFrame.style.width = "130px";                                       // set content frame width
    gadgetDockedFrame.style.height = "200px";                                      // set content frame height
    //gadgetNavDocked.style.display = "block";                                        // set nav bar content (for docked without fly) display style
    //gadgetNavUndockedSmall.style.display = "none";                                  // set nav bar content (for undocked small) display style
    //gadgetNavUndockedLarge.style.display = "none";                                  // set nav bar content (for undocked large) display style
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// doProcFlyoutOpen - process open flyout request
// 
///////////////////////////////////////////////////////////////////////////////////////////////////
function doProcFlyoutOpen() {   // process open flyout request
    gFlyOpenFlag = true;
    System.Gadget.Flyout.show = true;
}
///////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////