///////////////////////////////////////////////////////////////////////////////////////////////////
//	This script contains all business logic of getting Xml feed from theastrologer.com
//	Date: 		April 19, 2007
//	Version:	1.1.2
//	Developer:	Pranav Dixit
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// GLOBAL GADGET MEMBERS
//
///////////////////////////////////////////////////////////////////////////////////////////////////
var gHoroXmlFeedUrl = "http://theastrologer.com/feeds/horoscopes.xml";	// Horoscope live feed resource.
var gHoroXmlFeed = null;                                         		// Horoscope live feed Xml.
var gHoroCurDate = null;                                       			// Horoscope current date.
var gHoroSignNames = new Array();										// Horoscope Sun Sign array.
var gHoroSignText = new Array();                                        // Horoscope text data.
var gHoroRating = new Array();                                        	// Horoscope rating values.
var gHoroIntensity = new Array();										// Horoscope intensity values.
var gHoroKeywords = new Array();										// Horoscope Keywords values.
var gHoroMood = new Array();											// Horoscope mood values.
var gLastSignIndex = 0;									                // Remember the last Sun Sign selection.
var gLastSunSign = '';                                                  // Remember the last Sun Sign selection by user.
var gIsFirstLoad = true;                                                // Hold the boolean value for first initialization.
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// initHoroSettings - initializes Horoscope settings
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function initHoroSettings()
{   // init Horoscope settings

    // get birth date settings
    var sBirthDateSetting = readSetting("YourBirthDate");          // read default birthdate setting
    if (sBirthDateSetting === '') {
        // default to gYourBirthDate = Birthdate of Brad Pit (12/18/1963) (if YourBirthDate not yet set)) 
        sBirthDateSetting = "12/18/1963";                 // update default birth date
        saveSetting("YourBirthDate", sBirthDateSetting);  // write new setting
    }

    // get last SunSign selection
    gLastSunSign = readSetting("LastSunSign");              // read undock small flag setting
    last = gLastSunSign;
    if (gLastSunSign === '')
    {
        gLastSunSign = "Aries";                            // set default Sun Sign
        saveSetting("LastSunSign", gLastSunSign);          // write gLastSunSign value
    }
    gLastSignIndex = GetSunSignIndex( gLastSunSign );
    
    if(gIsFirstLoad) {
        gIsFirstLoad = false;
        refreshData();   //re-load data from feed again (refresh)
    }
    showHoroscope( sBirthDateSetting );
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// loaddata - load Xml feed from theastrologer.com
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function loaddata() {
  gHoroXmlFeed = new ActiveXObject("Msxml2.DOMDocument.3.0");
  gHoroXmlFeed.onreadystatechange = checkState;
  gHoroXmlFeed.load(gHoroXmlFeedUrl);
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// checkState - Check the Http response status for any errors.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function checkState() {
  var state = gHoroXmlFeed.readyState;
  if (state == 4) {
    var err = gHoroXmlFeed.parseError;
    if (err.errorCode != 0) {
      // Display error message.
      document.getElementById("horoTextArea").innerHTML = err.reason;
	} else {
		doParseXml();
    }
  }
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// doParseXml - ParseXml response and fill Horoscope arrays.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function doParseXml()
{   
    gHoroCurDate = doGetDataDate();
	var signNodes = gHoroXmlFeed.getElementsByTagName("SIGN");
	var nIndex;
	var signNode;
	for (nIndex=0; nIndex<signNodes.length; nIndex++) {	//Iterate all Sign node
	    signNode=signNodes.item(nIndex);
	    gHoroSignNames[nIndex]=getNoteData(signNode,"NAME");
	    gHoroSignText[nIndex]=getNoteData(signNode,"TEXT");
	    gHoroRating[nIndex]=getNoteData(signNode,"RATING");
	    gHoroIntensity[nIndex]=getNoteData(signNode,"INTENSITY") + "%";
	    gHoroKeywords[nIndex]=getNoteData(signNode,"KEYWORDS");
	    gHoroMood[nIndex]=getNoteData(signNode,"MOOD");
	}
	getHoroscope( gLastSignIndex );
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// getNoteData - Function: Get a Note's datavalue
//               paramater: first->current parse element obj
//			     second->note name
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function getNoteData(objPar,noteNamePar){
    return objPar.getElementsByTagName(noteNamePar).item(0).firstChild.nodeValue;
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// doGetDataDate - Function: Get current xml document datetime
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function doGetDataDate(){
    var dateTimeTmp=getNoteData(gHoroXmlFeed,"DATE");
	return getFormatedDate(dateTimeTmp);
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// refreshData - Function: re-load data from feed again (refresh)
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function refreshData() { 
    loaddata();    
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// refresh - Function: Refresh the horoscope in 300000 miliseconds.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function refresh() { 
    refreshData();
    window.setInterval(refreshData, 300000); 
}
///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// getHoroscope - Set horoscope details according to the Sun Sign.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function getHoroscope( pLastSign ) {
    //UnDocked Controls Start
	lblDate.innerHTML = gHoroCurDate;
	lblHoroData.innerHTML = gHoroSignText[pLastSign];
	imgRating.src = "Resources/Stars/" + gHoroRating[pLastSign] + ".png";
	lblIntensity.innerHTML = gHoroIntensity[pLastSign];
	lblKeywords.innerHTML = gHoroKeywords[pLastSign];
	lblMood.innerHTML = gHoroMood[pLastSign];
	imgSunSign.src = "Resources/SunSigns/" + gHoroSignNames[pLastSign] + ".png";
	imgSunSignText.src = "Resources/SunSignsText/" + gHoroSignNames[pLastSign] + ".png";
	//UnDocked Controls End
	//Docked Controls Start
	lblDHoroData.innerHTML = gHoroSignText[pLastSign];
	imgDSunSign.src = "Resources/SunSigns/" + gHoroSignNames[pLastSign] + ".png";
	imgDSunSignText.src = "Resources/SunSignsText/" + gHoroSignNames[pLastSign] + ".png";
	imgDRating.src = "Resources/Stars/" + gHoroRating[pLastSign] + ".png";
	//Docked Controls End
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// getFormatedDate - Convert BirthDate in MMM/DD/YYYY format.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function getFormatedDate( pBirthDate ) {
    var bDate = pBirthDate.split("/");
    if(bDate.length > 0)
    {
        var bMonth = GetMonthText( bDate[0] );
        return bMonth + " " + bDate[1] + ", " + bDate[2]
    }
    return pBirthDate;
}
///////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////
//
// showHoroscope - Set horoscope details according to the Birth Date.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function showHoroscope( pBirthDate ) {
    var bDate = pBirthDate.split("/");
    var bSunSign = GetSunSign( bDate[0], bDate[1] );
    gLastSignIndex = GetSunSignIndex( bSunSign );
    getHoroscope( gLastSignIndex );
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// doSwitch - Iterate Sun Sign forward/reverse direction.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function doSwitch( direction ) {
	if ( direction == "forward" ) {
		if ( gLastSignIndex == ( gHoroSignNames.length - 1 ) ) {
			gLastSignIndex = 0;
		} else {
			gLastSignIndex++;
		}
        gLastSunSign = gHoroSignNames[gLastSignIndex];
        saveSetting("LastSunSign", gLastSunSign)
        getHoroscope( gLastSignIndex );
	} else {
		if (gLastSignIndex == 0) {
			gLastSignIndex = (gHoroSignNames.length - 1);
		} else {
			gLastSignIndex--;
		}
        gLastSunSign = gHoroSignNames[gLastSignIndex];
		saveSetting("LastSunSign", gLastSunSign)
        getHoroscope( gLastSignIndex );
	}
}

///////////////////////////////////////////////////////////////////////////////////////////////////



///////////////////////////////////////////////////////////////////////////////////////////////////
//
// GetSunSignIndex - Get SunSignIndex for given Sun Sign.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function GetSunSignIndex( pSunSign )
{
    var nIndex = 0;
    switch(pSunSign)
    {
        case "Aries" : nIndex = 0; break;
        case "Taurus" : nIndex = 1; break;
        case "Gemini" : nIndex = 2; break;
        case "Cancer" : nIndex = 3; break;
        case "Leo" : nIndex = 4; break;
        case "Virgo" : nIndex = 5; break;
        case "Libra" : nIndex = 6; break;
        case "Scorpio" : nIndex = 7; break;
        case "Sagittarius" : nIndex = 8; break;
        case "Capricorn" : nIndex = 9; break;
        case "Aquarius" : nIndex = 10; break;
        case "Pisces" : nIndex = 11; break;
        default : nIndex = 0; break;
    }
    return nIndex;
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// GetSunSign - Get SunSign as per birth date.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function GetSunSign( Month, Day )
{
    var SunSign = "";
    switch(Month)
    {
        case "01" : (Day > 0 && Day < 20)? SunSign = "Capricorn" : SunSign = "Aquarius"; break;
        case "02" : (Day > 0 && Day < 19)? SunSign = "Aquarius" : SunSign = "Pisces"; break;
        case "03" : (Day > 0 && Day < 21)? SunSign = "Pisces" : SunSign = "Aries"; break;
        case "04" : (Day > 0 && Day < 20)? SunSign = "Aries" : SunSign = "Taurus"; break;
        case "05" : (Day > 0 && Day < 21)? SunSign = "Taurus" : SunSign = "Gemini"; break;
        case "06" : (Day > 0 && Day < 22)? SunSign = "Gemini" : SunSign = "Cancer"; break;
        case "07" : (Day > 0 && Day < 23)? SunSign = "Cancer" : SunSign = "Leo"; break;
        case "08" : (Day > 0 && Day < 23)? SunSign = "Leo" : SunSign = "Virgo"; break;
        case "09" : (Day > 0 && Day < 23)? SunSign = "Virgo" : SunSign = "Libra"; break;
        case "10" : (Day > 0 && Day < 23)? SunSign = "Libra" : SunSign = "Scorpio"; break;
        case "11" : (Day > 0 && Day < 22)? SunSign = "Scorpio" : SunSign = "Sagittarius"; break;
        case "12" : (Day > 0 && Day < 22)? SunSign = "Sagittarius" : SunSign = "Capricorn"; break;
        default : SunSign = "Aries"; break;
    }
    return SunSign;
}
///////////////////////////////////////////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////////////////////////////
//
// GetMonthText - Get Month text as per birth month.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
function GetMonthText( strMonth )
{
    var Month = "";
    switch(strMonth)
    {
        case "01" : Month = "January"; break;
        case "02" : Month = "February"; break;
        case "03" : Month = "March"; break;
        case "04" : Month = "April"; break;
        case "05" : Month = "May"; break;
        case "06" : Month = "June"; break;
        case "07" : Month = "July"; break;
        case "08" : Month = "August"; break;
        case "09" : Month = "September"; break;
        case "10" : Month = "October"; break;
        case "11" : Month = "November"; break;
        case "12" : Month = "December"; break;
        default : Month = "January"; break;
    }
    return Month;
}

///////////////////////////////////////////////////////////////////////////////////////////////////
//.................................................................................................
///////////////////////////////////////////////////////////////////////////////////////////////////


